/*
 * Copyright 2009 Andreas Borglin andreas.borglin@gmail.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package borge.mobile.lib.pimp;

/**
 * This interface contains constants needed for the image manipulation API.
 * Since static imports are not supported in Java 1.3, we use this interface
 * only to provide classes with direct access to commonly used constants.
 * @author Andreas Borglin
 */
public interface ImageConstants {
    // Image operation constants
    
    /** Constant for resize operation */
    public static final int RESIZE = 0;
    /** Constant for rotation operation */
    public static final int ROTATE = 1;
    /** Constant for flip operation */
    public static final int FLIP = 2;
    /** Constant for cropping operation */
    public static final int CROP = 3;
    /** Constant for framing operation */
    public static final int FRAME = 4;
    /** Constant for brightness operation */
    public static final int BRIGHTNESS = 5;
    /** Constant for contrast operation */
    public static final int CONTRAST = 6;
    /** Constant for effects operation */
    public static final int EFFECT = 7;
    /** Constant for overlay operation */
    public static final int OVERLAY = 8;
    /** Constant for white balance operation */
    public static final int WHITEBALANCE = 9;
    /** Constant for gamma operation */
    public static final int GAMMA = 10;
    /** The number of listed operations */
    public static final int OPERATIONS = 11;
    
    /** Generic value for unknown operations */
    public static final int UNKNOWN = -1;
    
    /** Generic flag for integers with no value */
    public static final int NO_VALUE = -1;
    
    /** Flag for rotating image 90 degrees */
    public static final int ROTATE_90 = 1;
    /** Flag for rotating image 180 degrees */
    public static final int ROTATE_180 = 2;
    /** Flag for rotating image 270 degrees */
    public static final int ROTATE_270 = 3;
    /** Flag for flipping image horizontally */
    public static final int FLIP_HORIZONTALLY = 1;
    /** Flag for flipping image vertically */
    public static final int FLIP_VERTICALLY = 2;

}
