/*
 * Copyright 2009 Andreas Borglin andreas.borglin@gmail.com
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package borge.mobile.lib.pimp;

import java.io.InputStream;

/**
 * This interface is necessary to create Image objects as input
 * for overlay handling. Our overlay handling can support Image objects
 * from different UI technologies (lcdui, swt, swing, etc), so
 * it is up to the application UI handler to create the image
 * object from a stream and return it as a generic object.
 * 
 * @author Andreas Borglin
 */
public interface ImageCreator {
   
    /**
     * Create application UI dependent Image object.
     * @param is InputStream with image data
     * @return An object reference to the Image
     */
    public Object createImage(InputStream is);

}
